# binette package

## Submodules

## binette.bin_manager module

```{eval-rst}
.. automodule:: binette.bin_manager
   :members:
   :undoc-members:
   :show-inheritance:
```

## binette.bin_quality module

```{eval-rst}
.. automodule:: binette.bin_quality
   :members:
   :undoc-members:
   :show-inheritance:
```

## binette.binette module

```{eval-rst}
.. automodule:: binette.binette
   :members:
   :undoc-members:
   :show-inheritance:
```

## binette.cds module

```{eval-rst}
.. automodule:: binette.cds
   :members:
   :undoc-members:
   :show-inheritance:
```

## binette.contig_manager module

```{eval-rst}
.. automodule:: binette.contig_manager
   :members:
   :undoc-members:
   :show-inheritance:
```

## binette.diamond module

```{eval-rst}
.. automodule:: binette.diamond
   :members:
   :undoc-members:
   :show-inheritance:
```

## binette.io_manager module

```{eval-rst}
.. automodule:: binette.io_manager
   :members:
   :undoc-members:
   :show-inheritance:
```

## Module contents

```{eval-rst}
.. automodule:: binette
   :members:
   :undoc-members:
   :show-inheritance:
```
